Changelog
---------

0.2.1 (2016-04-06)
~~~~~~~~~~~~~~~~~~~

- Adds compatibility with Morepath 0.13.
  [href]

0.2.0 (2016-04-05)
~~~~~~~~~~~~~~~~~~~

- Changes the mouse pointer to default on unclickable markers.
  [href]

- Fixes form submit not working with enter key in map enabled forms.
  [href]

- Acquires the default view parameters from the body.
  [href]

0.1.0 (2016-04-05)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to display a (readonly) map with a marker.
  [href]

0.0.1 (2016-04-01)
~~~~~~~~~~~~~~~~~~~

- Initial Release
